@@ -24,8 +24,8 @@ INVALID_CHARS = {
     "es": r"[^a-zA-ZÀ-ÿáéíñúüÁÉÍÑÓÚÜ]",
     "pt": r"[^a-zA-ZÀ-ÿ]",
     "it": r"[^a-zA-ZÀ-ÿ]",
-    "sv": r"[^a-zA-ZÆØÅæøåÉÈÊÓÒÂÔéèêóòâôç]",
-    "da": r"[^a-zA-ZÆØÅæøåÉÈÊÓÒÂÔéèêóòâôç]",
+    "sv": r"[^a-zA-ZÆØÅÄÖæøåäöÉÈÊÓÒÂÔéèêóòâôç]",
+    "da": r"[^a-zA-ZÆØÅÄÖæøåäöÉÈÊÓÒÂÔéèêóòâôç]",
     "fi": r"[^a-zA-ZÅÄÖåäöŠšŽž]",
     "no": r"[^a-zA-ZÆØÅæøåÉÈÊÓÒÂÔéèêóòâôç]",
     "ru": r"[^А-Яа-яЁё]",
